
# Class: Friend




URI: [ks:Friend](https://w3id.org/linkml/tests/kitchen_sink/Friend)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Friend&#124;name:string%20%3F])](https://yuml.me/diagram/nofunky;dir:TB/class/[Friend&#124;name:string%20%3F])

## Attributes


### Own

 * [name](name.md)  <sub>0..1</sub>
     * Range: [String](types/String.md)
